#
# spec file for package perl-Data-Visitor
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Data-Visitor
Name:           perl-Data-Visitor
Version:        0.32
Release:        1.9
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Visitor style traversal of Perl data structures
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETHER/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Moose) >= 0.89
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Needs)
BuildRequires:  perl(Tie::ToObject) >= 0.01
BuildRequires:  perl(namespace::clean) >= 0.19
Requires:       perl(Moose) >= 0.89
Requires:       perl(Tie::ToObject) >= 0.01
Requires:       perl(namespace::clean) >= 0.19
%{perl_requires}

%description
This module is a simple visitor implementation for Perl values.

It has a main dispatcher method, 'visit', which takes a single perl value
and then calls the methods appropriate for that value.

It can recursively map (cloning as necessary) or just traverse most
structures, with support for per object behavior, circular structures,
visiting tied structures, and all ref types (hashes, arrays, scalars, code,
globs).

Data::Visitor is meant to be subclassed, but also ships with a callback
driven subclass, Data::Visitor::Callback.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING README
%license LICENCE

%changelog
* Sun Apr 30 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.32
  see /usr/share/doc/packages/perl-Data-Visitor/Changes
  0.32      2023-04-29 10:07:45Z
  - removed an unnecessary use of Sub::Name (haarg, PR #1)
* Mon Aug  3 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.31
  see /usr/share/doc/packages/perl-Data-Visitor/Changes
  Revision history for Data-Visitor
  0.31      2020-08-02 22:39:31Z
  - updated distribution tooling (resolves RT#133059, a problem with the
    compilation test when the installed perl has whitespace in its path)
* Thu Jul 18 2013 coolo@suse.com
- updated to 0.30
  - doy/data-visitor should probably be the canonical repository at this
    point
  - The class callbacks to be run for an object are now chosen once, at the
    start of visiting that object. Previously, it always looked through the
    entire list of callbacks every time, in a loop in which the object in
    question could be changed by the callback. Since the class callbacks are
    only partially ordered, this lead to differences in whether a callback
    would be called or not based on hash order. reported by Robin Smidsrød.
* Mon Feb 27 2012 coolo@suse.com
- updated to 0.28
  - convert to dzil
  - bump namespace::clean dep
  - better error message if Data::Alias isn't found
  - doc fixes
* Thu Jul 14 2011 coolo@novell.com
- regenerate with cpanspec
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sat Jul 24 2010 pascal.bleser@opensuse.org
- initial package (0.27)
